@@ -1,48 +1,66 @@
 package aws
 
 import (
+	"context"
+
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
+	"github.com/infracost/infracost/internal/usage/aws"
 
 	"github.com/shopspring/decimal"
 )
 
-type LambdaFunctionArguments struct {
+type LambdaFunction struct {
 	Address    string
 	Region     string
+	Name       string
 	MemorySize int64
 
 	RequestDurationMS *float64 `infracost_usage:"request_duration_ms"`
 	MonthlyRequests   *float64 `infracost_usage:"monthly_requests"`
 }
 
-func (args *LambdaFunctionArguments) PopulateUsage(u *schema.UsageData) {
-	resources.PopulateArgsWithUsage(args, u)
-}
-
 var LambdaFunctionUsageSchema = []*schema.UsageSchemaItem{
 	{Key: "request_duration_ms", DefaultValue: 0, ValueType: schema.Float64},
 	{Key: "monthly_requests", DefaultValue: 0, ValueType: schema.Float64},
 }
 
-func NewLambdaFunction(args *LambdaFunctionArguments) *schema.Resource {
-	memorySize := decimal.NewFromInt(args.MemorySize)
+func (a *LambdaFunction) PopulateUsage(u *schema.UsageData) {
+	resources.PopulateArgsWithUsage(a, u)
+}
+
+func (a *LambdaFunction) BuildResource() *schema.Resource {
+	memorySize := decimal.NewFromInt(a.MemorySize)
 
 	averageRequestDuration := decimal.NewFromInt(1)
-	if args.RequestDurationMS != nil {
-		averageRequestDuration = decimal.NewFromFloat(*args.RequestDurationMS)
+	if a.RequestDurationMS != nil {
+		averageRequestDuration = decimal.NewFromFloat(*a.RequestDurationMS)
 	}
 
 	var monthlyRequests *decimal.Decimal
 	var gbSeconds *decimal.Decimal
 
-	if args.MonthlyRequests != nil {
-		monthlyRequests = decimalPtr(decimal.NewFromFloat(*args.MonthlyRequests))
+	if a.MonthlyRequests != nil {
+		monthlyRequests = decimalPtr(decimal.NewFromFloat(*a.MonthlyRequests))
 		gbSeconds = decimalPtr(calculateGBSeconds(memorySize, averageRequestDuration, *monthlyRequests))
 	}
 
+	estimate := func(ctx context.Context, values map[string]interface{}) error {
+		inv, err := aws.LambdaGetInvocations(ctx, a.Region, a.Name)
+		if err != nil {
+			return err
+		}
+		values["monthly_requests"] = inv
+		dur, err := aws.LambdaGetDurationAvg(ctx, a.Region, a.Name)
+		if err != nil {
+			return err
+		}
+		values["request_duration_ms"] = dur
+		return nil
+	}
+
 	return &schema.Resource{
-		Name:        args.Address,
+		Name:        a.Address,
 		UsageSchema: LambdaFunctionUsageSchema,
 		CostComponents: []*schema.CostComponent{
 			{
@@ -52,7 +70,7 @@ func NewLambdaFunction(args *LambdaFunctionArguments) *schema.Resource {
 				MonthlyQuantity: monthlyRequests,
 				ProductFilter: &schema.ProductFilter{
 					VendorName:    strPtr("aws"),
-					Region:        strPtr(args.Region),
+					Region:        strPtr(a.Region),
 					Service:       strPtr("AWSLambda"),
 					ProductFamily: strPtr("Serverless"),
 					AttributeFilters: []*schema.AttributeFilter{
@@ -68,7 +86,7 @@ func NewLambdaFunction(args *LambdaFunctionArguments) *schema.Resource {
 				MonthlyQuantity: gbSeconds,
 				ProductFilter: &schema.ProductFilter{
 					VendorName:    strPtr("aws"),
-					Region:        strPtr(args.Region),
+					Region:        strPtr(a.Region),
 					Service:       strPtr("AWSLambda"),
 					ProductFamily: strPtr("Serverless"),
 					AttributeFilters: []*schema.AttributeFilter{
@@ -78,6 +96,7 @@ func NewLambdaFunction(args *LambdaFunctionArguments) *schema.Resource {
 				},
 			},
 		},
+		EstimateUsage: estimate,
 	}
 }
 
